@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: axis.c,v 1.135.2.6 2015/02/23 21:34:45 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: axis.c,v 1.135.2.10 2016/04/14 20:13:52 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - axis.c */
@@ -148,6 +148,7 @@ const struct lp_style_type default_grid_lp = DEFAULT_GRID_LP;
 struct lp_style_type grid_lp   = DEFAULT_GRID_LP;
 struct lp_style_type mgrid_lp  = DEFAULT_GRID_LP;
 int grid_layer = LAYER_BEHIND;
+TBOOLEAN grid_tics_in_front = FALSE;
 double polar_grid_angle = 0;	/* nonzero means a polar grid */
 TBOOLEAN raxis = TRUE;
 
@@ -1268,7 +1269,7 @@ gen_tics(AXIS_INDEX axis, tic_callback callback)
 
 			/* Range-limited tic placement */
 			if (def->rangelimited
-			&&  !inrange(internal,this->data_min,this->data_max))
+			&&  !inrange(internal, this->data_min, this->data_max))
 			    continue;
 
 			(*callback) (axis, internal, label, 0, lgrd, def->def.user);
@@ -1298,7 +1299,14 @@ gen_tics(AXIS_INDEX axis, tic_callback callback)
 			       ? AXIS_DO_LOG(axis,mplace)
 			       : mplace);
 		    temptic = mtic;
-		    if (polar && axis == POLAR_AXIS) temptic += R_AXIS.min;
+		    if (polar && axis == POLAR_AXIS)
+			temptic += R_AXIS.min;
+
+		    /* Range-limited tic placement */
+		    if (def->rangelimited
+		    &&  !inrange(temptic, this->data_min, this->data_max))
+			continue;
+
 		    if (inrange(temptic, internal_min, internal_max)
 			&& inrange(temptic, start - step * SIGNIF, end + step * SIGNIF))
 			(*callback) (axis, mtic, NULL, 1, mgrd, NULL);
@@ -1593,7 +1601,7 @@ load_one_range(AXIS_INDEX axis, double *a, t_autoscale *autoscale, t_autoscale w
 		}
 		c_token++;
 	    } else {
-		int_error(c_token, "malformed range with constarint");
+		int_error(c_token, "malformed range with constraint");
             }
         } else if (equals(c_token, ">")) {
 	    int_error(c_token, "malformed range with constraint (use '<' only)");
@@ -1693,6 +1701,12 @@ load_range(AXIS_INDEX axis, double *a, double *b, t_autoscale autoscale)
 	load_one_range(axis, b, &autoscale, AUTOSCALE_MAX );
     }
 
+    /* Not all the code can deal nicely with +/- infinity */
+    if (*a < -VERYLARGE)
+	*a = -VERYLARGE;
+    if (*b > VERYLARGE)
+	*b = VERYLARGE;
+
     return (autoscale);
 }
 
@@ -2121,6 +2135,7 @@ void
 clone_linked_axes(AXIS_INDEX axis2, AXIS_INDEX axis1)
 {
     double testmin, testmax;
+    TBOOLEAN suspect = FALSE;
 
     memcpy(&axis_array[axis2], &axis_array[axis1], AXIS_CLONE_SIZE);
     if (axis_array[axis2].link_udf == NULL || axis_array[axis2].link_udf->at == NULL)
@@ -2136,14 +2151,18 @@ clone_linked_axes(AXIS_INDEX axis2, AXIS_INDEX axis1)
 	||  isnan(axis_array[axis2].max) || isnan(axis_array[axis2].set_max))
 	    int_warn(NO_CARET, "axis mapping function must return a real value");
 
-    /* Confirm that the inverse mapping actually works */
+    /* Confirm that the inverse mapping actually works, at least at the endpoints */
     /* FIXME:  Should we test values in between the endpoints also? */
 	testmin = eval_link_function(axis1, axis_array[axis2].set_min);
 	testmax = eval_link_function(axis1, axis_array[axis2].set_max);
-	if (fabs((testmin - axis_array[axis1].set_min) / testmin) < 1.e-6
-	&&  fabs((testmax - axis_array[axis1].set_max) / testmax) < 1.e-6) {
-	    /* OK */
-	} else {
+	if (fabs(testmin - axis_array[axis1].set_min) != 0
+	&&  fabs((testmin - axis_array[axis1].set_min) / testmin) > 1.e-6)
+	    suspect = TRUE;
+	if (fabs(testmax - axis_array[axis1].set_max) != 0
+	&&  fabs((testmax - axis_array[axis1].set_max) / testmax) > 1.e-6)
+	    suspect = TRUE;
+
+	if (suspect) {
 	    int_warn(NO_CARET, "could not confirm linked axis inverse mapping function");
 	    fprintf(stderr,"\tmin: %g inv(via(min)): %g", axis_array[axis1].set_min, testmin);
 	    fprintf(stderr,"  max: %g inv(via(max)): %g\n", axis_array[axis1].set_max, testmax);
