@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: gadgets.c,v 1.115.2.4 2015/03/29 18:08:04 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: gadgets.c,v 1.115.2.6 2016/07/08 20:48:34 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - gadgets.c */
@@ -339,8 +339,9 @@ clip_line(int *x1, int *y1, int *x2, int *y2)
      * but it might be better to hard-code the sign tests.
      */
     double dx, dy;
+    double x, y;
 
-    int x, y, x_intr[4], y_intr[4], count, pos1, pos2;
+    int x_intr[4], y_intr[4], count, pos1, pos2;
     int x_max, x_min, y_max, y_min;
     pos1 = clip_point(*x1, *y1);
     pos2 = clip_point(*x2, *y2);
@@ -779,31 +780,31 @@ write_label(unsigned int x, unsigned int y, struct text_label *this_label)
 	    }
 	}
 #ifdef EAM_BOXED_TEXT
-	/* Adjust the bounding box margins */
-	if (this_label->boxed && term->boxed_text)
+	if (this_label->boxed && term->boxed_text) {
+
+	    /* Adjust the bounding box margins */
 	    (*term->boxed_text)((int)(textbox_opts.xmargin * 100.),
 		(int)(textbox_opts.ymargin * 100.), TEXTBOX_MARGINS);
 
-	if (this_label->boxed && term->boxed_text && textbox_opts.opaque) {
 	    /* Blank out the box and reprint the label */
-	    (*term->boxed_text)(0,0, TEXTBOX_BACKGROUNDFILL);
-	    if (this_label->rotate && (*term->text_angle) (this_label->rotate)) {
-		write_multiline(x + htic, y + vtic, this_label->text,
-			    this_label->pos, justify, this_label->rotate,
-			    this_label->font);
-		(*term->text_angle) (0);
-	    } else {
-		write_multiline(x + htic, y + vtic, this_label->text,
-			    this_label->pos, justify, 0, this_label->font);
+	    if (textbox_opts.opaque) {
+		(*term->boxed_text)(0,0, TEXTBOX_BACKGROUNDFILL);
+		if (this_label->rotate && (*term->text_angle) (this_label->rotate)) {
+		    write_multiline(x + htic, y + vtic, this_label->text,
+				this_label->pos, justify, this_label->rotate,
+				this_label->font);
+		    (*term->text_angle) (0);
+		} else {
+		    write_multiline(x + htic, y + vtic, this_label->text,
+				this_label->pos, justify, 0, this_label->font);
+		}
 	    }
-	}
 
-	/* Draw the bounding box - FIXME should set line properties first */
-	if (this_label->boxed && term->boxed_text) {
+	    /* Draw the bounding box - FIXME should set line properties first */
 	    if (!textbox_opts.noborder)
 		(*term->boxed_text)(0,0, TEXTBOX_OUTLINE);
-	    else
-		(*term->boxed_text)(0,0, TEXTBOX_FINISH);
+
+	    (*term->boxed_text)(0,0, TEXTBOX_FINISH);
 	}
 #endif
 
