@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: plot3d.c,v 1.231.2.4 2015/10/31 04:39:20 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: plot3d.c,v 1.231.2.7 2016/06/18 05:59:25 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - plot3d.c */
@@ -1104,6 +1104,8 @@ get_3ddata(struct surface_points *this_plot)
 		if (NEED_PALETTE(this_plot)) {
 		    if (pm3d_color_from_column) {
 			COLOR_STORE_WITH_LOG_AND_UPDATE_RANGE(cp->CRD_COLOR, color, cp->type, COLOR_AXIS, this_plot->noautoscale, NOOP, goto come_here_if_undefined);
+			if (this_plot->plot_style == VECTOR)
+			    cphead->CRD_COLOR = color;
 		    } else {
 			COLOR_STORE_WITH_LOG_AND_UPDATE_RANGE(cp->CRD_COLOR, z, cp->type, COLOR_AXIS, this_plot->noautoscale, NOOP, goto come_here_if_undefined);
 		    }
@@ -1295,6 +1297,8 @@ eval_3dplots()
     int i;
     struct surface_points **tp_3d_ptr;
     int start_token=0, end_token;
+    int highest_iteration = 0;	/* last index reached in iteration [i=start:*] */
+    TBOOLEAN eof_during_iteration = FALSE;  /* set when for [n=start:*] hits NODATA */
     int begin_token;
     TBOOLEAN some_data_files = FALSE, some_functions = FALSE;
     TBOOLEAN was_definition = FALSE;
@@ -1413,6 +1417,7 @@ eval_3dplots()
 
 		this_plot->plot_type = DATA3D;
 		this_plot->plot_style = data_style;
+		eof_during_iteration = FALSE;
 
 		df_set_plot_mode(MODE_SPLOT);
 		specs = df_open(name_str, MAXDATACOLS, (struct curve_points *)this_plot);
@@ -1927,6 +1932,13 @@ eval_3dplots()
 
 	    if (empty_iteration(plot_iterator))
 		this_plot->plot_type = NODATA;
+	    if (forever_iteration(plot_iterator) && (this_plot->plot_type == NODATA)) {
+		highest_iteration = plot_iterator->iteration;
+		eof_during_iteration = TRUE;
+	    }
+	    if (forever_iteration(plot_iterator) && (this_plot->plot_type == FUNC3D)) {
+		int_error(NO_CARET, "unbounded iteration in function plot");
+	    }
 
 	}			/* !is_definition() : end of scope of this_plot */
 
@@ -1939,8 +1951,11 @@ eval_3dplots()
 	}
 
 	/* Iterate-over-plot mechanisms */
-	if (next_iteration(plot_iterator)) {
+	if (eof_during_iteration) {
+	    /* Nothing to do */ ;
+	} else if (next_iteration(plot_iterator)) {
 	    c_token = start_token;
+	    highest_iteration = plot_iterator->iteration;
 	    continue;
 	}
 
@@ -2123,8 +2138,10 @@ eval_3dplots()
 
 	    /* Iterate-over-plot mechanism */
 	    if (crnt_param == 0 && next_iteration(plot_iterator)) {
-		c_token = start_token;
-		continue;
+		if (plot_iterator->iteration <= highest_iteration) {
+		    c_token = start_token;
+		    continue;
+		}
 	    }
 
 	    if (crnt_param == 0)
