@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: save.c,v 1.256.2.14 2015/02/26 18:43:46 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: save.c,v 1.256.2.18 2016/05/04 21:56:07 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - save.c */
@@ -139,6 +139,7 @@ save_variables__sub(FILE *fp)
 	    if (strncmp(udv->udv_name,"GPVAL_",6)
 	     && strncmp(udv->udv_name,"MOUSE_",6)
 	     && strncmp(udv->udv_name,"$",1)
+	     && (strncmp(udv->udv_name,"ARG",3) || (strlen(udv->udv_name) != 4))
 	     && strncmp(udv->udv_name,"NaN",4)) {
 		fprintf(fp, "%s = ", udv->udv_name);
 		disp_value(fp, &(udv->udv_value), TRUE);
@@ -333,9 +334,7 @@ set bar %f %s\n",
     fprintf(fp, "set angles %s\n",
 	    (ang2rad == 1.0) ? "radians" : "degrees");
 
-    /* Grid back/front controls tics also. Make sure it is saved */
-    if (grid_layer >= 0)
-	fprintf(fp,"set tics %s\n", grid_layer == LAYER_BACK ? "back" : "front");
+    fprintf(fp,"set tics %s\n", grid_tics_in_front ? "front" : "back");
 
     if (! some_grid_selected())
 	fputs("unset grid\n", fp);
@@ -792,7 +791,7 @@ set origin %g,%g\n",
 	save_textcolor(fp, &(lab.textcolor));				 \
 	if (lab.tag == ROTATE_IN_3D_LABEL_TAG)				 \
 	    fprintf(fp, " rotate parallel");				 \
-	if (lab.rotate)							 \
+	else if (lab.rotate)						 \
 	    fprintf(fp, " rotate by %d", lab.rotate);			 \
 	else								 \
 	    fprintf(fp, " norotate");					 \
@@ -1489,6 +1488,9 @@ save_data_func_style(FILE *fp, const char *which, enum PLOT_STYLE style)
     case SURFACEGRID:
 	fputs("surfaces\n", fp);
 	break;
+    case PARALLELPLOT:
+	fputs("parallelaxes\n", fp);
+	break;
     case PLOT_STYLE_NONE:
     default:
 	fputs("---error!---\n", fp);
