@@ -1,5 +1,5 @@
 /*
- * $Id: term_api.h,v 1.134.2.8 2015/12/30 18:48:01 sfeam Exp $
+ * $Id: term_api.h,v 1.134.2.9 2016/01/18 23:51:59 sfeam Exp $
  */
 
 /* GNUPLOT - term_api.h */
@@ -237,11 +237,6 @@ typedef enum t_fillstyle { FS_EMPTY, FS_SOLID, FS_PATTERN, FS_DEFAULT,
 /* Color construction for an image, palette lookup or rgb components. */
 typedef enum t_imagecolor { IC_PALETTE, IC_RGB, IC_RGBA }
 	     t_imagecolor;
-/* Holder for various image properties */
-typedef struct t_image {
-    t_imagecolor type; /* See above */
-    TBOOLEAN fallback; /* true == don't use terminal-specific code */
-} t_image;
 
 /* Operations possible with term->modify_plots() */
 #define MODPLOTS_SET_VISIBLE         (1<<0)
@@ -266,6 +261,7 @@ typedef struct t_image {
 #define TERM_IS_LATEX        (1<<13)	/* text uses TeX markup            */
 #define TERM_EXTENDED_COLOR  (1<<14)	/* uses EXTENDED_COLOR_SPECS       */
 #define TERM_NULL_SET_COLOR  (1<<15)	/* no support for RGB color        */
+#define TERM_POLYGON_PIXELS  (1<<16)	/* filledpolygon rather than fillbox */
 
 /* The terminal interface structure --- heart of the terminal layer.
  *
