@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: version.c,v 1.100.2.11 2014/09/21 15:58:36 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: version.c,v 1.111.2.13 2016/07/15 06:08:34 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - version.c */
@@ -39,10 +39,14 @@ static char *RCSid() { return RCSid("$Id: version.c,v 1.100.2.11 2014/09/21 15:5
 #include "syscfg.h"		/* for FAQ_LOCATION */
 
 
-const char gnuplot_version[] = "4.6";
-const char gnuplot_patchlevel[] = "6";
-const char gnuplot_date[] = "September 2014";
-const char gnuplot_copyright[] = "Copyright (C) 1986-1993, 1998, 2004, 2007-2014";
+const char gnuplot_version[] = "5.0";
+const char gnuplot_patchlevel[] = "4";
+#ifdef DEVELOPMENT_VERSION
+#include "timestamp.h"
+#else
+const char gnuplot_date[] = "2016-07-15 ";
+#endif
+const char gnuplot_copyright[] = "Copyright (C) 1986-1993, 1998, 2004, 2007-2016";
 
 const char faq_location[] = FAQ_LOCATION;
 
@@ -50,6 +54,3 @@ char *compile_options = (void *)0;	/* Will be loaded at runtime */
 
 const char bug_email[] = "gnuplot-beta@lists.sourceforge.net";
 const char help_email[] = "gnuplot-beta@lists.sourceforge.net";
-
-char os_name[32];
-char os_rel[32];
