@@ -1,5 +1,5 @@
 /*
- * $Id: wxt_gui.h,v 1.36.2.5 2014/07/03 21:47:18 markisch Exp $
+ * $Id: wxt_gui.h,v 1.48.2.6 2016/03/22 17:08:36 markisch Exp $
  */
 
 /* GNUPLOT - wxt_gui.h */
@@ -81,6 +81,9 @@
 #include <wx/dataobj.h>
 #include <wx/clipbrd.h>
 
+/* Save File dialog */
+#include <wx/filedlg.h>
+
 /* wxImage facility */
 #include <wx/image.h>
 
@@ -99,6 +102,9 @@
 /* wxMemoryInputStream, for the embedded PNG icons */
 #include <wx/mstream.h>
 
+/* Debugging support, required to turn off asserts */
+#include <wx/debug.h>
+
 /* c++ vectors and lists, used to store gnuplot commands */
 #include <vector>
 #include <list>
@@ -129,10 +135,7 @@ extern "C" {
 #endif
 
 /* With wxGTK, we use a different cairo surface starting from gtk28 */
-#if defined(__WXGTK__)&&defined(HAVE_GTK28)
-# define GTK_SURFACE
-#endif
-#if defined(__WXGTK__)&&!defined(HAVE_GTK28)
+#if defined(__WXGTK__)
 # define IMAGE_SURFACE
 #endif
 
@@ -168,7 +171,7 @@ extern "C" {
  * redefinition of fprintf, getch...
  * console window */
 # ifdef _Windows
-#  ifndef _WIN32_WINNT
+#  ifndef _WIN32_WINNT 
 #   define _WIN32_WINNT 0x0500
 #  endif
 #  include "Windows.h"
@@ -179,6 +182,14 @@ extern "C" {
 /* for cairo_t */
 # include <cairo.h>
 
+#ifdef CAIRO_HAS_SVG_SURFACE
+#include <cairo/cairo-svg.h>
+#endif
+
+#ifdef CAIRO_HAS_PDF_SURFACE
+#include <cairo/cairo-pdf.h>
+#endif
+
 # ifdef USE_GTK
 #  include <gdk/gdk.h>
 #  include <gtk/gtk.h>
@@ -208,6 +219,11 @@ extern "C" {
  * ====================================================================*/
 
 #ifdef WXT_MULTITHREADED
+
+#if defined(WX_NEEDS_XINITTHREADS) && defined(X11)
+#include <X11/Xlib.h>	/* Magic fix for linking against wxgtk3.0 */
+#endif
+
 /* thread class, where the gui loop runs.
  * Not needed with Windows, where the main loop
  * already processes the gui messages */
@@ -224,21 +240,26 @@ public:
 static wxtThread * thread;
 #endif /* WXT_MULTITHREADED */
 
-DECLARE_EVENT_TYPE(wxExitLoopEvent, -1)
-DEFINE_EVENT_TYPE(wxExitLoopEvent)
+DECLARE_LOCAL_EVENT_TYPE(wxExitLoopEvent, -1)
+DEFINE_LOCAL_EVENT_TYPE(wxExitLoopEvent)
 
-DECLARE_EVENT_TYPE(wxCreateWindowEvent, -1)
-DEFINE_EVENT_TYPE(wxCreateWindowEvent)
+DECLARE_LOCAL_EVENT_TYPE(wxCreateWindowEvent, -1)
+DEFINE_LOCAL_EVENT_TYPE(wxCreateWindowEvent)
 
 #ifdef USE_MOUSE
-DECLARE_EVENT_TYPE(wxStatusTextEvent, -1)
-DEFINE_EVENT_TYPE(wxStatusTextEvent)
+DECLARE_LOCAL_EVENT_TYPE(wxStatusTextEvent, -1)
+DEFINE_LOCAL_EVENT_TYPE(wxStatusTextEvent)
 #endif /* USE_MOUSE */
 
 /* Define a new application type, each gui should derive a class from wxApp */
 class wxtApp : public wxApp
 {
 public:
+#if defined(WXT_MULTITHREADED) && defined(WX_NEEDS_XINITTHREADS) && defined(X11)
+	/* Magic fix needed by wxgtk3.0 */
+        wxtApp() : wxApp() { XInitThreads(); } 
+#endif 
+
 	/* This one is called just after wxWidgets initialization */
 	bool OnInit();
 	/* cleanup on exit */
@@ -281,7 +302,12 @@ typedef enum wxt_gp_command_t {
 	command_fillbox,
 	command_filled_polygon,
 	command_image,
-	command_layer
+	command_layer,
+	command_hypertext
+#ifdef EAM_BOXED_TEXT
+	,command_boxed_text
+#endif
+	,command_dashtype
 } wxt_gp_command_t;
 
 /* base structure for storing gnuplot commands */
@@ -299,6 +325,7 @@ typedef struct gp_command {
 	int integer_value2;
 	double double_value;
 	double double_value2;
+	t_dashtype *dashpattern;
 	char *string;
 	gpiPoint *corners;
 	enum JUSTIFY mode;
@@ -376,6 +403,7 @@ public :
 	/* functions used to process the command list */
 	void wxt_cairo_refresh();
 	void wxt_cairo_exec_command(gp_command command);
+	void wxt_cairo_draw_hypertext();
 
 	/* the plot structure, defined in gp_cairo.h */
 	plot_struct plot;
@@ -439,6 +467,7 @@ class wxtConfigDialog : public wxDialog
 	bool persist_setting;
 	bool ctrl_setting;
 	bool toggle_setting;
+	bool redraw_setting;
 	/* rendering_setting :
 	 * 0 = no antialiasing, no oversampling
 	 * 1 = antialiasing, no oversampling
@@ -460,6 +489,7 @@ public:
 	void OnClose( wxCloseEvent& event );
 	void OnSize( wxSizeEvent& event );
 	void OnCopy( wxCommandEvent& event );
+	void OnExport( wxCommandEvent& event );
 #ifdef USE_MOUSE
 	void OnReplot( wxCommandEvent& event );
 	void OnToggleGrid( wxCommandEvent& event );
@@ -479,6 +509,8 @@ public:
 
 	wxtPanel * panel;
 	bool config_displayed;
+	wxToolBar * toolbar;
+
 private:
 	wxtConfigDialog * config_dialog;
 
@@ -490,6 +522,7 @@ private:
 enum {
 /* start at wxID_HIGHEST to avoid collisions */
 Toolbar_CopyToClipboard = wxID_HIGHEST,
+Toolbar_ExportToFile,
 Toolbar_Replot,
 Toolbar_ToggleGrid,
 Toolbar_ZoomPrevious,
@@ -516,11 +549,6 @@ static wxCursor wxt_cursor_right;
 static wxCursor wxt_cursor_rotate;
 static wxCursor wxt_cursor_size;
 
-#ifdef DEBUG
- /* performance watch */
- static wxStopWatch sw;
-#endif
-
 /* wxt_abort_init is set to true if there is an error when
  * wxWidgets is initialized, for example if the X server is unreachable.
  * If there has been an error, we should not try to initialize again,
@@ -581,6 +609,7 @@ static void wxt_command_push(gp_command command);
  * not if the window is not the current one. */
 static bool wxt_exec_event(int type, int mx, int my, int par1, int par2, wxWindowID id);
 static void wxt_check_for_toggle(unsigned int x, unsigned int y);
+static void wxt_check_for_anchors(unsigned int x, unsigned int y);
 
 /* process one event, returns true if it ends the pause */
 static bool wxt_process_one_event(struct gp_event_t *);
